@@ -13,7 +13,6 @@ object and then create the configurable objects, passing the config to them.
 # Distributed under the terms of the Modified BSD License.
 
 import atexit
-from copy import deepcopy
 import glob
 import logging
 import os
@@ -27,10 +26,7 @@ from IPython.core.profiledir import ProfileDir, ProfileDirError
 from IPython.paths import get_ipython_dir, get_ipython_package_dir
 from IPython.utils.path import ensure_dir_exists
 from IPython.utils import py3compat
-from traitlets import (
-    List, Unicode, Type, Bool, Dict, Set, Instance, Undefined,
-    default, observe,
-)
+from traitlets import List, Unicode, Type, Bool, Dict, Set, Instance, Undefined
 
 if os.name == 'nt':
     programdata = os.environ.get('PROGRAMDATA', None)
@@ -45,24 +41,6 @@ else:
     ]
 
 
-ENV_CONFIG_DIRS = []
-_env_config_dir = os.path.join(sys.prefix, 'etc', 'ipython')
-if _env_config_dir not in SYSTEM_CONFIG_DIRS:
-    # only add ENV_CONFIG if sys.prefix is not already included
-    ENV_CONFIG_DIRS.append(_env_config_dir)
-
-
-_envvar = os.environ.get('IPYTHON_SUPPRESS_CONFIG_ERRORS')
-if _envvar in {None, ''}:
-    IPYTHON_SUPPRESS_CONFIG_ERRORS = None
-else:
-    if _envvar.lower() in {'1','true'}:
-        IPYTHON_SUPPRESS_CONFIG_ERRORS = True
-    elif _envvar.lower() in {'0','false'} :
-        IPYTHON_SUPPRESS_CONFIG_ERRORS = False
-    else:
-        sys.exit("Unsupported value for environment variable: 'IPYTHON_SUPPRESS_CONFIG_ERRORS' is set to '%s' which is none of  {'0', '1', 'false', 'true', ''}."% _envvar )
-
 # aliases and flags
 
 base_aliases = {
@@ -118,13 +96,11 @@ class BaseIPythonApplication(Application):
     config_file_specified = Set()
 
     config_file_name = Unicode()
-    @default('config_file_name')
     def _config_file_name_default(self):
         return self.name.replace('-','_') + u'_config.py'
-    @observe('config_file_name')
-    def _config_file_name_changed(self, change):
-        if change['new'] != change['old']:
-            self.config_file_specified.add(change['new'])
+    def _config_file_name_changed(self, name, old, new):
+        if new != old:
+            self.config_file_specified.add(new)
 
     # The directory that contains IPython's builtin profiles.
     builtin_profile_dir = Unicode(
@@ -132,19 +108,15 @@ class BaseIPythonApplication(Application):
     )
     
     config_file_paths = List(Unicode())
-    @default('config_file_paths')
     def _config_file_paths_default(self):
         return [py3compat.getcwd()]
 
-    extra_config_file = Unicode(
+    extra_config_file = Unicode(config=True,
     help="""Path to an extra config file to load.
     
     If specified, load this config file in addition to any other IPython config.
-    """).tag(config=True)
-    @observe('extra_config_file')
-    def _extra_config_file_changed(self, change):
-        old = change['old']
-        new = change['new']
+    """)
+    def _extra_config_file_changed(self, name, old, new):
         try:
             self.config_files.remove(old)
         except ValueError:
@@ -152,37 +124,30 @@ class BaseIPythonApplication(Application):
         self.config_file_specified.add(new)
         self.config_files.append(new)
 
-    profile = Unicode(u'default',
+    profile = Unicode(u'default', config=True,
         help="""The IPython profile to use."""
-    ).tag(config=True)
-    
-    @observe('profile')
-    def _profile_changed(self, change):
+    )
+
+    def _profile_changed(self, name, old, new):
         self.builtin_profile_dir = os.path.join(
-                get_ipython_package_dir(), u'config', u'profile', change['new']
+                get_ipython_package_dir(), u'config', u'profile', new
         )
 
-    ipython_dir = Unicode(
+    ipython_dir = Unicode(config=True,
         help="""
         The name of the IPython directory. This directory is used for logging
         configuration (through profiles), history storage, etc. The default
         is usually $HOME/.ipython. This option can also be specified through
         the environment variable IPYTHONDIR.
         """
-    ).tag(config=True)
-    @default('ipython_dir')
+    )
     def _ipython_dir_default(self):
         d = get_ipython_dir()
-        self._ipython_dir_changed({
-            'name': 'ipython_dir',
-            'old': d,
-            'new': d,
-        })
+        self._ipython_dir_changed('ipython_dir', d, d)
         return d
     
     _in_init_profile_dir = False
     profile_dir = Instance(ProfileDir, allow_none=True)
-    @default('profile_dir')
     def _profile_dir_default(self):
         # avoid recursion
         if self._in_init_profile_dir:
@@ -191,29 +156,26 @@ class BaseIPythonApplication(Application):
         self.init_profile_dir()
         return self.profile_dir
 
-    overwrite = Bool(False,
-        help="""Whether to overwrite existing config files when copying"""
-    ).tag(config=True)
-    auto_create = Bool(False,
-        help="""Whether to create profile dir if it doesn't exist"""
-    ).tag(config=True)
+    overwrite = Bool(False, config=True,
+        help="""Whether to overwrite existing config files when copying""")
+    auto_create = Bool(False, config=True,
+        help="""Whether to create profile dir if it doesn't exist""")
 
     config_files = List(Unicode())
-    @default('config_files')
     def _config_files_default(self):
         return [self.config_file_name]
 
-    copy_config_files = Bool(False,
+    copy_config_files = Bool(False, config=True,
         help="""Whether to install the default config files into the profile dir.
         If a new profile is being created, and IPython contains config files for that
         profile, then they will be staged into the new directory.  Otherwise,
         default config files will be automatically generated.
-        """).tag(config=True)
+        """)
     
-    verbose_crash = Bool(False,
+    verbose_crash = Bool(False, config=True,
         help="""Create a massive crash report when IPython encounters what may be an
         internal error.  The default is to append a short message to the
-        usual traceback""").tag(config=True)
+        usual traceback""")
 
     # The class to use as the crash handler.
     crash_handler_class = Type(crashhandler.CrashHandler)
@@ -237,10 +199,15 @@ class BaseIPythonApplication(Application):
     
     def initialize_subcommand(self, subc, argv=None):
         if subc in self.deprecated_subcommands:
+            import time
             self.log.warning("Subcommand `ipython {sub}` is deprecated and will be removed "
                              "in future versions.".format(sub=subc))
-            self.log.warning("You likely want to use `jupyter {sub}` in the "
-                             "future".format(sub=subc))
+            self.log.warning("You likely want to use `jupyter {sub}`... continue "
+                             "in 5 sec. Press Ctrl-C to quit now.".format(sub=subc))
+            try:
+                time.sleep(5)
+            except KeyboardInterrupt:
+                sys.exit(1)
         return super(BaseIPythonApplication, self).initialize_subcommand(subc, argv)
 
     def init_crash_handler(self):
@@ -262,11 +229,8 @@ class BaseIPythonApplication(Application):
             return self.crash_handler(etype, evalue, tb)
         else:
             return crashhandler.crash_handler_lite(etype, evalue, tb)
-
-    @observe('ipython_dir')
-    def _ipython_dir_changed(self, change):
-        old = change['old']
-        new = change['new']
+    
+    def _ipython_dir_changed(self, name, old, new):
         if old is not Undefined:
             str_old = py3compat.cast_bytes_py2(os.path.abspath(old),
                 sys.getfilesystemencoding()
@@ -291,33 +255,18 @@ class BaseIPythonApplication(Application):
                 self.log.error("couldn't create path %s: %s", path, e)
         self.log.debug("IPYTHONDIR set to: %s" % new)
 
-    def load_config_file(self, suppress_errors=IPYTHON_SUPPRESS_CONFIG_ERRORS):
+    def load_config_file(self, suppress_errors=True):
         """Load the config file.
 
         By default, errors in loading config are handled, and a warning
         printed on screen. For testing, the suppress_errors option is set
         to False, so errors will make tests fail.
-
-        `supress_errors` default value is to be `None` in which case the
-        behavior default to the one of `traitlets.Application`.
-
-        The default value can be set :
-           - to `False` by setting 'IPYTHON_SUPPRESS_CONFIG_ERRORS' environment variable to '0', or 'false' (case insensitive).
-           - to `True` by setting 'IPYTHON_SUPPRESS_CONFIG_ERRORS' environment variable to '1' or 'true' (case insensitive).
-           - to `None` by setting 'IPYTHON_SUPPRESS_CONFIG_ERRORS' environment variable to '' (empty string) or leaving it unset.
-
-        Any other value are invalid, and will make IPython exit with a non-zero return code.
         """
-
-
         self.log.debug("Searching path %s for config files", self.config_file_paths)
         base_config = 'ipython_config.py'
         self.log.debug("Attempting to load config file: %s" %
                        base_config)
         try:
-            if suppress_errors is not None:
-                old_value = Application.raise_config_file_errors
-                Application.raise_config_file_errors = not suppress_errors;
             Application.load_config_file(
                 self,
                 base_config,
@@ -327,8 +276,6 @@ class BaseIPythonApplication(Application):
             # ignore errors loading parent
             self.log.debug("Config file %s not found", base_config)
             pass
-        if suppress_errors is not None:
-            Application.raise_config_file_errors = old_value
         
         for config_file_name in self.config_files:
             if not config_file_name or config_file_name == base_config:
@@ -411,7 +358,6 @@ class BaseIPythonApplication(Application):
 
     def init_config_files(self):
         """[optionally] copy default config files into profile dir."""
-        self.config_file_paths.extend(ENV_CONFIG_DIRS)
         self.config_file_paths.extend(SYSTEM_CONFIG_DIRS)
         # copy config files
         path = self.builtin_profile_dir
@@ -457,9 +403,7 @@ class BaseIPythonApplication(Application):
         if self.subapp is not None:
             # stop here if subapp is taking over
             return
-        # save a copy of CLI config to re-load after config files
-        # so that it has highest priority
-        cl_config = deepcopy(self.config)
+        cl_config = self.config
         self.init_profile_dir()
         self.init_config_files()
         self.load_config_file()
